@@ -17,10 +17,10 @@ class LanguageIdentifier:
     def rank(self, text:str):
         return self.model.rank(text)
 
-# lid = LanguageIdentifier(Path(__file__).parent/'LID_mixed_model.pkl')
+lid = LanguageIdentifier(Path(__file__).parent/'LID_mixed_model.pkl')
 # print(str(pickle.loads(pkgutil.get_data('LanguageIdentifier', 'LID_mixed_model.pkl'))))
-d = os.path.join(os.path.dirname(sys.modules['LanguageIdentifier'].__file__), 'LID_mixed_model.pkl')
-lid = LanguageIdentifier(d)
+# d = os.path.join(os.path.dirname(sys.modules['LanguageIdentifier'].__file__), 'LID_mixed_model.pkl')
+# lid = LanguageIdentifier(d)
 def predict(text:str):
     return lid.predict(text)
 def rank(text:str):
